pub struct Chain { /* private fields */ }Expand description
Implementation of kinematic chains
segments: a vector with the segments of the chain
num_joints: number of joints (segments with movable joints)
num_ind_joints: Number of joints with independent movement
num_unlocked_joints: Num of enabled/unlocked joints
locked_joints: vector with bools indicating if the joint is locked
coupling_matrix: matrix correlating the joints with their couples\
Implementations
Sourceimpl Chain
impl Chain
Sourcepub fn get_num_segments(&self) -> usize
pub fn get_num_segments(&self) -> usize
Returns the total number of segments
Sourcepub fn get_num_joints(&self) -> usize
pub fn get_num_joints(&self) -> usize
Returns the number of segments with moveable joints
Sourcepub fn get_num_ind_joints(&self) -> usize
pub fn get_num_ind_joints(&self) -> usize
Returns the number of Independent moveable joints
Sourcepub fn get_coupling_matrix(&self) -> DMatrix<f64>
pub fn get_coupling_matrix(&self) -> DMatrix<f64>
Returns the coupling matrix
Sourcepub fn add_segment(&mut self, segment: Segment)
pub fn add_segment(&mut self, segment: Segment)
Add a new semgment at the end of the kinematic chain
(Where the end is where the end-effector would be)
Sourcepub fn get_segment(&self, index: usize) -> Segment
pub fn get_segment(&self, index: usize) -> Segment
Get the segment at the index-th position
Sourcepub fn get_locked_joints(&self) -> Vec<bool>
pub fn get_locked_joints(&self) -> Vec<bool>
Get the vector with lock information