pub struct ForwardDiffKinematicsSolver { /* private fields */ }Expand description
Solver for forward differential kinematics. Calculate the velocity at any given joint from the current joint configuration and rate.
Implementations
Sourceimpl ForwardDiffKinematicsSolver
impl ForwardDiffKinematicsSolver
Sourcepub fn solve_at_segment(
&self,
angles: &Vec<f64>,
qdots: &Vec<f64>,
segment_index: usize,
) -> Twist
pub fn solve_at_segment( &self, angles: &Vec<f64>, qdots: &Vec<f64>, segment_index: usize, ) -> Twist
Solver for forward differential kinematics at an arbitrary segment.
Computes the twist at the segment given the current chain state.
chain: Kinematic chain to use by the solver
angles: vector with the state at each joint
qdots: vector with the differential state at each joint
segment_index: at which segment to compute the velocity\