Segment

Struct Segment 

pub struct Segment { /* private fields */ }
Implementation of a kinematic chian segment. This is the joint together with the link.

It is represented by the joint, a frame that transforms from the joint to the end of the link, and an inertia parameter.

Implementations

Source

impl Segment

pub fn default() -> Segment

Default segment, with the default joint and no link.

pub fn new(joint: Joint, f_tip: Frame, inertia: RigidBodyInertia) -> Segment

Constructs a segment from the given Joint, link transformation and inertia

pub fn set_joint(&self, new_joint: Joint) -> Segment

Creates a new segment with the given joint

pub fn set_tip_frame(&self, new_f_tip: Frame) -> Segment

Creates a new segment with the given link transformation

pub fn set_inertia(&self, new_inertia: RigidBodyInertia) -> Segment

Creates a new segment with the given inertia

Note that right now this method is useless because dynamics are not yet implemented

pub fn get_joint_type(&self) -> JointType

Returns the type of the internal joint

Returns the link transfrom

pub fn pose(&self, joint_state: f64) -> Frame

Get the pose at the tip of the segment given the state of the joint

pub fn twist(&self, joint_state: f64, qdot: f64) -> Twist

Get the twist at the tip of the segment given the state of the joint