pub struct Segment { /* private fields */ }Expand description
Implementation of a kinematic chian segment. This is the joint together with the link.
It is represented by the joint, a frame that transforms from the joint to the end of the link, and an inertia parameter.
Implementations
Sourceimpl Segment
impl Segment
Sourcepub fn new(joint: Joint, f_tip: Frame, inertia: RigidBodyInertia) -> Segment
pub fn new(joint: Joint, f_tip: Frame, inertia: RigidBodyInertia) -> Segment
Constructs a segment from the given Joint, link transformation
and inertia
Sourcepub fn set_joint(&self, new_joint: Joint) -> Segment
pub fn set_joint(&self, new_joint: Joint) -> Segment
Creates a new segment with the given joint
Sourcepub fn set_tip_frame(&self, new_f_tip: Frame) -> Segment
pub fn set_tip_frame(&self, new_f_tip: Frame) -> Segment
Creates a new segment with the given link transformation
Sourcepub fn set_inertia(&self, new_inertia: RigidBodyInertia) -> Segment
pub fn set_inertia(&self, new_inertia: RigidBodyInertia) -> Segment
Creates a new segment with the given inertia
Note that right now this method is useless because dynamics are not yet implemented
Sourcepub fn get_joint_type(&self) -> JointType
pub fn get_joint_type(&self) -> JointType
Returns the type of the internal joint
Sourcepub fn get_link_transform(&self) -> Frame
pub fn get_link_transform(&self) -> Frame
Returns the link transfrom